Confidence Lifecycle Scheduler
This module implements automatic confidence decay and lifecycle management for genes and capsules within the evolution crate.
Structs
- Bayesian
Confidence Updater - Bayesian confidence updater using a Beta-Bernoulli conjugate model.
- Beta
Prior - Per-class Beta-distribution prior.
- Confidence
Controller - Continuous confidence controller for genes and capsules.
- Confidence
Metrics - Confidence metrics
- Confidence
Scheduler Config - Confidence scheduler configuration
- Confidence
Snapshot - A snapshot of the current Bayesian posterior for an asset’s confidence.
- Controller
Config - Configuration for
ConfidenceController. - Downgrade
Event - An observability event emitted whenever an asset is automatically
downgraded by the
ConfidenceController. - Outcome
Record - A single outcome record associated with an asset.
- Standard
Confidence Scheduler - Standard implementation of confidence scheduler
Enums
- Confidence
Action - Confidence update action
- Scheduler
Error - Scheduler errors
Traits
- Confidence
Scheduler - Trait for confidence lifecycle management
Functions
- builtin_
priors - Return the canonical built-in priors.
- process_
capsule_ confidence - Apply decay to a capsule and return actions