SignalExtractorPort

Trait SignalExtractorPort 

pub trait SignalExtractorPort: Send + Sync {
    // Required method
    fn extract(&self, input: &SignalExtractorInput) -> Vec<EvolutionSignal>;
}
Trait for signal extractors that can be injected into the Detect stage.

Implement this in oris-evokernel (or any crate that does not form a circular dependency with oris-evolution) and pass an Arc<dyn SignalExtractorPort> when constructing StandardEvolutionPipeline.

Required Methods

fn extract(&self, input: &SignalExtractorInput) -> Vec<EvolutionSignal>

Extract evolution signals from the given runtime input.

Returns a (possibly empty) list of signals. The implementation is responsible for deduplication and confidence scoring.

Implementors