Confidence Lifecycle Scheduler
This module implements automatic confidence decay and lifecycle management for genes and capsules within the evolution crate.
Structs
- Confidence
Metrics - Confidence metrics
- Confidence
Scheduler Config - Confidence scheduler configuration
- Standard
Confidence Scheduler - Standard implementation of confidence scheduler
Enums
- Confidence
Action - Confidence update action
- Scheduler
Error - Scheduler errors
Traits
- Confidence
Scheduler - Trait for confidence lifecycle management
Functions
- process_
capsule_ confidence - Apply decay to a capsule and return actions